@@ -1,5 +1,6 @@
 import click
 
+from adam.commands.audit.audit import Audit, AuditCommandHelper
 from adam.commands.bash import Bash
 from adam.commands.check import Check, CheckCommandHelper
 from adam.commands.cp import ClipboardCopy, CopyCommandHelper
@@ -29,6 +30,15 @@ from adam.repl import enter_repl
 from adam.repl_state import ReplState
 from adam.cli_group import cli
 
+@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=AuditCommandHelper, help='Run audit functions.')
+@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
+@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
+@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
+@click.argument('extra_args', nargs=-1, metavar='repair', type=click.UNPROCESSED)
+def audit(kubeconfig: str, config: str, param: list[str], extra_args):
+    run_command(Audit(), kubeconfig, config, param, None, None, None, extra_args)
+
+
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterOrPodCommandHelper, help='Run a single bash command.')
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
 @click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
