@@ -59,6 +59,8 @@ class Cd(Command):
                         state.app_env = dir.split('@')[0]
                     else:
                         state.app_app = dir
+            elif state.device == ReplState.L:
+                pass
             else:
                 if dir == '':
                     state.sts = None
@@ -103,7 +105,7 @@ class Cd(Command):
                 return {Cd.COMMAND: {'..': None} | {app[0].split('-')[1]: None for app in Apps.apps(state.app_env)}}
             else:
                 return {Cd.COMMAND: {'..': None} | {env[0]: None for env in Apps.envs()}}
-        else:
+        elif state.device == ReplState.C:
             if state.pod:
                 return {Cd.COMMAND: {'..': None}}
             elif state.sts:
