@@ -5,7 +5,6 @@ from adam.commands.deploy.deploy_pg_agent import DeployPgAgent
 from adam.commands.deploy.deploy_pod import DeployPod
 from .deploy_frontend import DeployFrontend
 from adam.repl_state import ReplState
-from adam.utils import lines_to_tabular, log, log2
 
 class Deploy(Command):
     COMMAND = 'deploy'
@@ -27,18 +26,7 @@ class Deploy(Command):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
-        state, args = self.apply_state(args, state)
-
-        if state.in_repl:
-            log(lines_to_tabular([c.help(ReplState()) for c in Deploy.cmd_list()], separator='\t'))
-
-            return 'command-missing'
-        else:
-            # head with the Chain of Responsibility pattern
-            cmds = Command.chain(Deploy.cmd_list())
-            if not cmds.run(cmd, state):
-                log2('* Command is missing.')
-                Command.display_help()
+        return super().intermediate_run(cmd, state, args, Deploy.cmd_list())
 
     def cmd_list():
         return [DeployFrontend(), DeployPod(), DeployPgAgent()]
@@ -49,13 +37,6 @@ class Deploy(Command):
 
         return {}
 
-    def help(self, _: ReplState):
-        return None
-
 class DeployCommandHelper(click.Command):
     def get_help(self, ctx: click.Context):
-        log(super().get_help(ctx))
-        log()
-        log('Sub-Commands:')
-
-        log(lines_to_tabular([c.help(ReplState()).replace(f'{Deploy.COMMAND} ', '  ', 1) for c in Deploy.cmd_list()], separator='\t'))
\ No newline at end of file
+        Command.intermediate_help(super().get_help(ctx), Deploy.COMMAND, Deploy.cmd_list())
\ No newline at end of file
