@@ -5,7 +5,6 @@ from adam.commands.deploy.undeploy_frontend import UndeployFrontend
 from adam.commands.deploy.undeploy_pg_agent import UndeployPgAgent
 from adam.commands.deploy.undeploy_pod import UndeployPod
 from adam.repl_state import ReplState
-from adam.utils import lines_to_tabular, log, log2
 
 class Undeploy(Command):
     COMMAND = 'undeploy'
@@ -27,18 +26,7 @@ class Undeploy(Command):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
-        state, args = self.apply_state(args, state)
-
-        if state.in_repl:
-            log(lines_to_tabular([c.help(ReplState()) for c in Undeploy.cmd_list()], separator='\t'))
-
-            return 'command-missing'
-        else:
-            # head with the Chain of Responsibility pattern
-            cmds = Command.chain(Undeploy.cmd_list())
-            if not cmds.run(cmd, state):
-                log2('* Command is missing.')
-                Command.display_help()
+        return super().intermediate_run(cmd, state, args, Undeploy.cmd_list())
 
     def cmd_list():
         return [UndeployFrontend(), UndeployPod(), UndeployPgAgent()]
@@ -49,13 +37,6 @@ class Undeploy(Command):
 
         return {}
 
-    def help(self, _: ReplState):
-        return None
-
 class UndeployCommandHelper(click.Command):
     def get_help(self, ctx: click.Context):
-        log(super().get_help(ctx))
-        log()
-        log('Sub-Commands:')
-
-        log(lines_to_tabular([c.help(ReplState()).replace(f'{Undeploy.COMMAND} ', '  ', 1) for c in Undeploy.cmd_list()], separator='\t'))
\ No newline at end of file
+        Command.intermediate_help(super().get_help(ctx), Undeploy.COMMAND, Undeploy.cmd_list())
\ No newline at end of file
