@@ -38,4 +38,4 @@ class UndeployFrontend(Command):
         return super().completion(state)
 
     def help(self, _: ReplState):
-        return f'{UndeployFrontend.COMMAND}\t undeploy frontend'
\ No newline at end of file
+        return f'{UndeployFrontend.COMMAND}\t undeploy Web frontend'
\ No newline at end of file
