@@ -14,6 +14,7 @@ from adam.pod_exec_result import PodExecResult
 from adam.repl_state import ReplState
 from adam.utils import lines_to_tabular, log, log2
 from adam.apps import Apps
+from adam.utils_athena import audit_table_names
 
 class Ls(Command):
     COMMAND = 'ls'
@@ -71,6 +72,8 @@ class Ls(Command):
                 svcs = [n for n, ns in Apps.envs()]
 
                 log(lines_to_tabular(svcs, 'ENV', separator=','))
+        elif state.device == ReplState.L:
+            self.show_audit_log_tables()
         else:
             if state.pod:
                 r: PodExecResult = Cqlsh().run(f'cql describe tables', state)
@@ -127,6 +130,9 @@ class Ls(Command):
     def show_pg_tables(self, pg: PostgresSession):
         log(lines_to_tabular(pg_table_names(pg.namespace, pg.directory()), 'NAME', separator=','))
 
+    def show_audit_log_tables(self):
+        log(lines_to_tabular(audit_table_names(), 'NAME', separator=','))
+
     def completion(self, state: ReplState):
         if state.pod:
             return {}
