@@ -1,7 +1,8 @@
-import functools
 import click
 
 from adam.commands.command import Command
+from adam.commands.postgres.psql_completions import psql_completions
+from adam.commands.postgres.postgres_utils import pg_table_names
 from .postgres_ls import PostgresLs
 from .postgres_preview import PostgresPreview
 from .postgres_session import PostgresSession
@@ -64,23 +65,15 @@ class Postgres(Command):
         PostgresSession(state.namespace, state.pg_path).run_sql(' '.join(args))
 
     def completion(self, state: ReplState):
+        if state.device != state.P:
+            # conflicts with cql completions
+            return {}
+
         leaf = {}
         session = PostgresSession(state.namespace, state.pg_path)
         if session.db:
-            ts = self.tables(state.namespace, state.pg_path)
-            leaf = {
-                '\h': None,
-                '\d': None,
-                '\dt': None,
-                '\du': None,
-                'delete': {'from': {t: {'where': {'id': {'=': None}}} for t in ts}},
-                'insert': {'into': {t: {'values': None} for t in ts}},
-                'select': {'*': {'from': {t: {
-                    'limit': {'1': None},
-                    'where': {'id': {'=': None}}
-                } for t in ts}}},
-                'update': {t: {'set': None} for t in ts},
-            }
+          if pg_table_names(state.namespace, state.pg_path):
+            leaf = psql_completions(state.namespace, state.pg_path)
         elif state.pg_path:
             leaf = {
                 '\h': None,
@@ -92,15 +85,6 @@ class Postgres(Command):
         else:
             return {}
 
-    # TODO fix cache
-    # @functools.lru_cache()
-    def tables(self, ns: str, pg_path: str):
-        session = PostgresSession(ns, pg_path)
-        if session.db:
-            return [f'{t["schema"]}.{t["name"]}' for t in session.tables()]
-
-        return []
-
     def help(self, _: ReplState):
         return f'[{Postgres.COMMAND}] <sql-statements>\t run psql with queries'
 
