@@ -5,6 +5,7 @@ from adam.commands.medusa.medusa_show_backupjobs import MedusaShowBackupJobs
 from adam.commands.medusa.medusa_show_restorejobs import MedusaShowRestoreJobs
 from adam.commands.show.show_app_actions import ShowAppActions
 from adam.commands.show.show_app_queues import ShowAppQueues
+from adam.commands.show.show_host import ShowHost
 from adam.commands.show.show_login import ShowLogin
 from .show_params import ShowParams
 from .show_app_id import ShowAppId
@@ -39,7 +40,7 @@ class Show(Command):
         return super().intermediate_run(cmd, state, args, Show.cmd_list())
 
     def cmd_list():
-        return [ShowAppActions(), ShowAppId(), ShowAppQueues(), ShowLogin(), ShowKubectlCommands(),
+        return [ShowAppActions(), ShowAppId(), ShowAppQueues(), ShowHost(), ShowLogin(), ShowKubectlCommands(),
                 ShowParams(), ShowProcesses(), ShowRepairs(), ShowStorage(), ShowAdam(),
                 ShowCassandraStatus(), ShowCassandraVersion(), MedusaShowRestoreJobs(), MedusaShowBackupJobs()]
 
