@@ -24,11 +24,12 @@ class StatefulSets:
 
         return statefulsets.items
 
+    @functools.lru_cache()
     def list_sts_name_and_ns():
         return [(statefulset.metadata.name, statefulset.metadata.namespace) for statefulset in StatefulSets.list_sts()]
 
-    def list_sts_names(show_namespace = True):
-        if show_namespace:
+    def list_sts_names():
+        if not KubeContext.in_cluster_namespace():
             return [f"{sts}@{ns}" for sts, ns in StatefulSets.list_sts_name_and_ns()]
         else:
             return [f"{sts}" for sts, _ in StatefulSets.list_sts_name_and_ns()]
