@@ -1,10 +1,13 @@
+import getpass
 import os
 import re
 import time
 import traceback
 import click
+import concurrent
 from prompt_toolkit.completion import NestedCompleter
 from prompt_toolkit.key_binding import KeyBindings
+import requests
 
 from adam.cli_group import cli
 from adam.commands.command import Command
@@ -20,6 +23,7 @@ from adam.repl_session import ReplSession
 from adam.repl_state import ReplState
 from adam.utils import deep_merge_dicts, deep_sort_dict, lines_to_tabular, log2
 from adam.apps import Apps
+from adam.utils_net import get_my_host
 from . import __version__
 
 def enter_repl(state: ReplState):
@@ -47,6 +51,8 @@ def enter_repl(state: ReplState):
                 msg += state.app_env
             if state.app_app:
                 msg += f'/{state.app_app}'
+        elif state.device == ReplState.L:
+            msg = f'{ReplState.L}:'
         else:
             msg = f'{ReplState.C}:'
             if state.pod:
@@ -92,73 +98,103 @@ def enter_repl(state: ReplState):
     def _(event):
         event.app.current_buffer.text = ''
 
-    # use sorted command list only for auto-completion
-    sorted_cmds = sorted(cmd_list, key=lambda cmd: cmd.command())
-    while True:
-        try:
-            completer = NestedCompleter.from_nested_dict({})
-            if not state.bash_session:
-                completions = {}
-                # app commands are available only on a: drive
-                if state.device == ReplState.A and state.app_app:
-                    completions = Apps(path='apps.yaml').commands()
+    with concurrent.futures.ThreadPoolExecutor(max_workers=Config().get('audit.workers', 3)) as executor:
+        # warm up AWS lambda - this log line may timeout and get lost, which is fine
+        executor.submit(audit_log, 'entering kaqing repl', state)
 
-                for cmd in sorted_cmds:
-                    s1 = time.time()
-                    try:
-                        completions = deep_sort_dict(deep_merge_dicts(completions, cmd.completion(state)))
-                    finally:
-                        if Config().get('debugs.timings', False):
-                            log2(f'Timing auto-completion-calc {cmd.command()}: {time.time() - s1:.2f}')
+        # use sorted command list only for auto-completion
+        sorted_cmds = sorted(cmd_list, key=lambda cmd: cmd.command())
+        while True:
+            try:
+                completer = NestedCompleter.from_nested_dict({})
+                if not state.bash_session:
+                    completions = {}
+                    # app commands are available only on a: drive
+                    if state.device == ReplState.A and state.app_app:
+                        completions = Apps(path='apps.yaml').commands()
 
-                # print(json.dumps(completions, indent=4))
-                completer = NestedCompleter.from_nested_dict(completions)
+                    for cmd in sorted_cmds:
+                        s1 = time.time()
+                        try:
+                            completions = deep_sort_dict(deep_merge_dicts(completions, cmd.completion(state)))
+                        finally:
+                            if Config().get('debugs.timings', False):
+                                log2(f'Timing auto-completion-calc {cmd.command()}: {time.time() - s1:.2f}')
 
-            cmd = session.prompt(prompt_msg(), completer=completer, key_bindings=kb)
-            s0 = time.time()
+                    # print(json.dumps(completions, indent=4))
+                    completer = NestedCompleter.from_nested_dict(completions)
 
-            if state.bash_session:
-                if cmd.strip(' ') == 'exit':
-                    state.exit_bash()
-                    continue
+                cmd = session.prompt(prompt_msg(), completer=completer, key_bindings=kb)
+                s0 = time.time()
 
-                cmd = f'bash {cmd}'
+                if state.bash_session:
+                    if cmd.strip(' ') == 'exit':
+                        state.exit_bash()
+                        continue
 
-            if cmd and cmd.strip(' ') and not cmds.run(cmd, state):
-                c_sql_tried = False
-                if state.device == ReplState.P:
-                    pg = PostgresSession(state.namespace, state.pg_path)
-                    if pg.db:
+                    cmd = f'bash {cmd}'
+
+                if cmd and cmd.strip(' ') and not cmds.run(cmd, state):
+                    c_sql_tried = False
+                    if state.device == ReplState.P:
+                        pg = PostgresSession(state.namespace, state.pg_path)
+                        if pg.db:
+                            c_sql_tried = True
+                            cmd = f'pg {cmd}'
+                            cmds.run(cmd, state)
+                    elif state.device == ReplState.A:
+                        if state.app_app:
+                            c_sql_tried = True
+                            cmd = f'app {cmd}'
+                            cmds.run(cmd, state)
+                    elif state.device == ReplState.L:
                         c_sql_tried = True
-                        cmd = f'pg {cmd}'
+                        cmd = f'audit {cmd}'
                         cmds.run(cmd, state)
-                elif state.device == ReplState.A:
-                    if state.app_app:
+                    elif state.sts:
                         c_sql_tried = True
-                        cmd = f'app {cmd}'
+                        cmd = f'cql {cmd}'
                         cmds.run(cmd, state)
-                elif state.sts:
-                    c_sql_tried = True
-                    cmd = f'cql {cmd}'
-                    cmds.run(cmd, state)
 
-                if not c_sql_tried:
-                    log2(f'* Invalid command: {cmd}')
-                    log2()
-                    lines = [c.help(state) for c in cmd_list if c.help(state)]
-                    log2(lines_to_tabular(lines, separator='\t'))
-        except EOFError:  # Handle Ctrl+D (EOF) for graceful exit
-            break
-        except Exception as e:
-            if Config().get('debugs.exit-on-error', False):
-                raise e
-            else:
-                log2(e)
-                Config().debug(traceback.format_exc())
-        finally:
-            Config().clear_wait_log_flag()
-            if Config().get('debugs.timings', False) and 'cmd' in locals() and 's0' in locals():
-                log2(f'Timing command {cmd}: {time.time() - s0:.2f}')
+                    if not c_sql_tried:
+                        log2(f'* Invalid command: {cmd}')
+                        log2()
+                        lines = [c.help(state) for c in cmd_list if c.help(state)]
+                        log2(lines_to_tabular(lines, separator='\t'))
+            except EOFError:  # Handle Ctrl+D (EOF) for graceful exit
+                break
+            except Exception as e:
+                if Config().get('debugs.exit-on-error', False):
+                    raise e
+                else:
+                    log2(e)
+                    Config().debug(traceback.format_exc())
+            finally:
+                Config().clear_wait_log_flag()
+                if Config().get('debugs.timings', False) and 'cmd' in locals() and 's0' in locals():
+                    log2(f'Timing command {cmd}: {time.time() - s0:.2f}')
+
+                # offload audit logging
+                if cmd and (state.device != ReplState.L or Config().get('audit.log-audit-queries', False)):
+                    executor.submit(audit_log, cmd, state)
+
+def audit_log(cmd: str, state: ReplState):
+    payload = {
+        'cluster': state.namespace if state.namespace else 'NA',
+        'ts': time.time(),
+        'host': get_my_host(),
+        'user': getpass.getuser(),
+        'line': cmd.replace('"', '""').replace('\n', ' '),
+    }
+    audit_endpoint = Config().get("audit.endpoint", "https://4psvtaxlcb.execute-api.us-west-2.amazonaws.com/prod/")
+    try:
+        response = requests.post(audit_endpoint, json=payload, timeout=Config().get("audit.timeout", 10))
+        if response.status_code in [200, 201]:
+            Config().debug(response.text)
+        else:
+            log2(f"Error: {response.status_code} {response.text}")
+    except requests.exceptions.Timeout as e:
+        log2(f"Timeout occurred: {e}")
 
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterCommandHelper, help="Enter interactive shell.")
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
