@@ -1,6 +1,8 @@
 from adam.commands.alter_tables import AlterTables
 from adam.commands.app import App
 from adam.commands.app_ping import AppPing
+from adam.commands.audit.audit import Audit
+from adam.commands.audit.audit_repair_tables import AuditRepairTables
 from adam.commands.deploy.code_start import CodeStart
 from adam.commands.deploy.code_stop import CodeStop
 from adam.commands.deploy.deploy import Deploy
@@ -24,7 +26,7 @@ from adam.commands.cd import Cd
 from adam.commands.check import Check
 from adam.commands.command import Command
 from adam.commands.cql.cqlsh import Cqlsh
-from adam.commands.devices import DeviceApp, DeviceCass, DevicePostgres
+from adam.commands.devices import DeviceApp, DeviceAuditLog, DeviceCass, DevicePostgres
 from adam.commands.exit import Exit
 from adam.commands.medusa.medusa import Medusa
 from adam.commands.param_get import GetParam
@@ -46,6 +48,7 @@ from adam.commands.show.show_app_id import ShowAppId
 from adam.commands.show.show_cassandra_status import ShowCassandraStatus
 from adam.commands.show.show_cassandra_version import ShowCassandraVersion
 from adam.commands.show.show_commands import ShowKubectlCommands
+from adam.commands.show.show_host import ShowHost
 from adam.commands.show.show_login import ShowLogin
 from adam.commands.show.show_params import ShowParams
 from adam.commands.show.show_processes import ShowProcesses
@@ -76,8 +79,8 @@ class ReplCommands:
         return deduped
 
     def navigation() -> list[Command]:
-        return [Ls(), PreviewTable(), DeviceApp(), DevicePostgres(), DeviceCass(), Cd(), Pwd(), ClipboardCopy(),
-                GetParam(), SetParam(), ShowParams(), ShowKubectlCommands(), ShowLogin(), ShowAdam()]
+        return [Ls(), PreviewTable(), DeviceApp(), DevicePostgres(), DeviceCass(), DeviceAuditLog(), Cd(), Pwd(), ClipboardCopy(),
+                GetParam(), SetParam(), ShowParams(), ShowKubectlCommands(), ShowLogin(), ShowAdam(), ShowHost()]
 
     def cassandra_check() -> list[Command]:
         return Describe.cmd_list() + [ShowCassandraStatus(),
@@ -88,7 +91,7 @@ class ReplCommands:
 
     def tools() -> list[Command]:
         return [Cqlsh(), Postgres(), Bash(), Shell(), CodeStart(), CodeStop(), DeployFrontend(), UndeployFrontend(),
-                DeployPod(), UndeployPod(), DeployPgAgent(), UndeployPgAgent()]
+                DeployPod(), UndeployPod(), DeployPgAgent(), UndeployPgAgent(), AuditRepairTables(), Audit()]
 
     def app() -> list[Command]:
         return [ShowAppActions(), ShowAppId(), ShowAppQueues(), AppPing(), App()]
