@@ -48,6 +48,7 @@ class RequiredState(Enum):
 class ReplState:
     A = 'a'
     C = 'c'
+    L = 'l'
     P = 'p'
 
     def __init__(self, device: str = None,
@@ -129,7 +130,7 @@ class ReplState:
             if index < 6:
                 state = copy.copy(state)
 
-                groups = re.match(r'^([a|c|p]):(.*)$', arg)
+                groups = re.match(r'^([a|c|l|p]):(.*)$', arg)
                 if groups:
                     if groups[1] == 'p':
                         state.device = 'p'
@@ -146,6 +147,8 @@ class ReplState:
                                 state.namespace = p_and_ns[1]
                             elif ns := KubeContext.in_cluster_namespace():
                                 state.namespace = ns
+                    elif groups[1] == 'l':
+                        state.device = 'l'
                     else:
                         state.device = 'a'
                         if path := groups[2]:
